@@ -81,6 +81,18 @@ ProvenanceTableRow = collections.namedtuple(
     ["timestamp", "record"])
 
 
+def keep_with_offset(keep, data, offset):
+    """
+    Used when filtering _offset columns in tables
+    """
+    # We need the astype here for 32 bit machines
+    lens = np.diff(offset).astype(np.int32)
+    return (data[np.repeat(keep, lens)],
+            np.concatenate([
+                np.array([0], dtype=offset.dtype),
+                np.cumsum(lens[keep], dtype=offset.dtype)]))
+
+
 class BaseTable(object):
     """
     Superclass of high-level tables. Not intended for direct instantiation.
@@ -187,7 +199,7 @@ class BaseTable(object):
 
     def set_columns(self, **kwargs):
         """
-        Sets the values for each column in this :class:`.Table` using
+        Sets the values for each column in this :class:`Table` using
         values provided in numpy arrays. Overwrites any data currently stored in
         the table.
         """
@@ -282,7 +294,7 @@ class IndividualTable(BaseTable, MetadataMixin):
             self, flags=None, location=None, location_offset=None,
             metadata=None, metadata_offset=None):
         """
-        Sets the values for each column in this :class:`.IndividualTable` using the
+        Sets the values for each column in this :class:`IndividualTable` using the
         values in the specified arrays. Overwrites any data currently stored in
         the table.
 
@@ -423,9 +435,9 @@ class NodeTable(BaseTable, MetadataMixin):
         :param int flags: The bitwise flags for the new node.
         :param float time: The birth time for the new node.
         :param int population: The ID of the population in which the new node was born.
-            Defaults to :const:`.NULL`.
+            Defaults to :data:`tskit.NULL`.
         :param int individual: The ID of the individual in which the new node was born.
-            Defaults to :const:`.NULL`.
+            Defaults to :data:`tskit.NULL`.
         :param bytes metadata: The binary-encoded metadata for the new node. If not
             specified or None, a zero-length byte string is stored.
         :return: The ID of the newly added node.
@@ -437,7 +449,7 @@ class NodeTable(BaseTable, MetadataMixin):
             self, flags=None, time=None, population=None, individual=None, metadata=None,
             metadata_offset=None):
         """
-        Sets the values for each column in this :class:`.NodeTable` using the values in
+        Sets the values for each column in this :class:`NodeTable` using the values in
         the specified arrays. Overwrites any data currently stored in the table.
 
         The ``flags``, ``time`` and ``population`` arrays must all be of the same length,
@@ -451,10 +463,10 @@ class NodeTable(BaseTable, MetadataMixin):
         :param time: The time values for each node. Required.
         :type time: numpy.ndarray, dtype=np.float64
         :param population: The population values for each node. If not specified
-            or None, the :const:`.NULL` value is stored for each node.
+            or None, the :data:`tskit.NULL` value is stored for each node.
         :type population: numpy.ndarray, dtype=np.int32
         :param individual: The individual values for each node. If not specified
-            or None, the :const:`.NULL` value is stored for each node.
+            or None, the :data:`tskit.NULL` value is stored for each node.
         :type individual: numpy.ndarray, dtype=np.int32
         :param metadata: The flattened metadata array. Must be specified along
             with ``metadata_offset``. If not specified or None, an empty metadata
@@ -486,10 +498,10 @@ class NodeTable(BaseTable, MetadataMixin):
         :param time: The time values for each node. Required.
         :type time: numpy.ndarray, dtype=np.float64
         :param population: The population values for each node. If not specified
-            or None, the :const:`.NULL` value is stored for each node.
+            or None, the :data:`tskit.NULL` value is stored for each node.
         :type population: numpy.ndarray, dtype=np.int32
         :param individual: The individual values for each node. If not specified
-            or None, the :const:`.NULL` value is stored for each node.
+            or None, the :data:`tskit.NULL` value is stored for each node.
         :type individual: numpy.ndarray, dtype=np.int32
         :param metadata: The flattened metadata array. Must be specified along
             with ``metadata_offset``. If not specified or None, an empty metadata
@@ -562,7 +574,7 @@ class EdgeTable(BaseTable):
 
     def set_columns(self, left=None, right=None, parent=None, child=None):
         """
-        Sets the values for each column in this :class:`.EdgeTable` using the values
+        Sets the values for each column in this :class:`EdgeTable` using the values
         in the specified arrays. Overwrites any data currently stored in the table.
 
         All four parameters are mandatory, and must be numpy arrays of the
@@ -687,7 +699,7 @@ class MigrationTable(BaseTable):
     def set_columns(
             self, left=None, right=None, node=None, source=None, dest=None, time=None):
         """
-        Sets the values for each column in this :class:`.MigrationTable` using the values
+        Sets the values for each column in this :class:`MigrationTable` using the values
         in the specified arrays. Overwrites any data currently stored in the table.
 
         All six parameters are mandatory, and must be numpy arrays of the
@@ -807,7 +819,7 @@ class SiteTable(BaseTable, MetadataMixin):
             self, position=None, ancestral_state=None, ancestral_state_offset=None,
             metadata=None, metadata_offset=None):
         """
-        Sets the values for each column in this :class:`.SiteTable` using the values
+        Sets the values for each column in this :class:`SiteTable` using the values
         in the specified arrays. Overwrites any data currently stored in the table.
 
         The ``position``, ``ancestral_state`` and ``ancestral_state_offset``
@@ -977,7 +989,7 @@ class MutationTable(BaseTable, MetadataMixin):
             self, site=None, node=None, derived_state=None, derived_state_offset=None,
             parent=None, metadata=None, metadata_offset=None):
         """
-        Sets the values for each column in this :class:`.MutationTable` using the values
+        Sets the values for each column in this :class:`MutationTable` using the values
         in the specified arrays. Overwrites any data currently stored in the table.
 
         The ``site``, ``node``, ``derived_state`` and ``derived_state_offset``
@@ -1128,10 +1140,43 @@ class PopulationTable(BaseTable, MetadataMixin):
         return ret[:-1]
 
     def set_columns(self, metadata=None, metadata_offset=None):
+        """
+        Sets the values for each column in this :class:`PopulationTable` using the
+        values in the specified arrays. Overwrites any data currently stored in the
+        table.
+
+        The ``metadata`` and ``metadata_offset`` parameters must be supplied
+        together, and meet the requirements for
+        :ref:`sec_encoding_ragged_columns` (see
+        :ref:`sec_tables_api_binary_columns` for more information).
+
+        :param metadata: The flattened metadata array. Must be specified along
+            with ``metadata_offset``. If not specified or None, an empty metadata
+            value is stored for each node.
+        :type metadata: numpy.ndarray, dtype=np.int8
+        :param metadata_offset: The offsets into the ``metadata`` array.
+        :type metadata_offset: numpy.ndarray, dtype=np.uint32.
+        """
         self.ll_table.set_columns(
             dict(metadata=metadata, metadata_offset=metadata_offset))
 
     def append_columns(self, metadata=None, metadata_offset=None):
+        """
+        Appends the specified arrays to the end of the columns of this
+        :class:`PopulationTable`. This allows many new rows to be added at once.
+
+        The ``metadata`` and ``metadata_offset`` parameters must be supplied
+        together, and meet the requirements for
+        :ref:`sec_encoding_ragged_columns` (see
+        :ref:`sec_tables_api_binary_columns` for more information).
+
+        :param metadata: The flattened metadata array. Must be specified along
+            with ``metadata_offset``. If not specified or None, an empty metadata
+            value is stored for each node.
+        :type metadata: numpy.ndarray, dtype=np.int8
+        :param metadata_offset: The offsets into the ``metadata`` array.
+        :type metadata_offset: numpy.ndarray, dtype=np.uint32.
+        """
         self.ll_table.append_columns(
             dict(metadata=metadata, metadata_offset=metadata_offset))
 
@@ -1189,6 +1234,30 @@ class ProvenanceTable(BaseTable):
     def set_columns(
             self, timestamp=None, timestamp_offset=None,
             record=None, record_offset=None):
+        """
+        Sets the values for each column in this :class:`ProvenanceTable` using the
+        values in the specified arrays. Overwrites any data currently stored in the
+        table.
+
+        The ``timestamp`` and ``timestamp_offset`` parameters must be supplied
+        together, and meet the requirements for
+        :ref:`sec_encoding_ragged_columns` (see
+        :ref:`sec_tables_api_binary_columns` for more information). Likewise
+        for the ``record`` and ``record_offset`` columns
+
+        :param timestamp: The flattened timestamp array. Must be specified along
+            with ``timestamp_offset``. If not specified or None, an empty timestamp
+            value is stored for each node.
+        :type timestamp: numpy.ndarray, dtype=np.int8
+        :param timestamp_offset: The offsets into the ``timestamp`` array.
+        :type timestamp_offset: numpy.ndarray, dtype=np.uint32.
+        :param record: The flattened record array. Must be specified along
+            with ``record_offset``. If not specified or None, an empty record
+            value is stored for each node.
+        :type record: numpy.ndarray, dtype=np.int8
+        :param record_offset: The offsets into the ``record`` array.
+        :type record_offset: numpy.ndarray, dtype=np.uint32.
+        """
         self.ll_table.set_columns(dict(
             timestamp=timestamp, timestamp_offset=timestamp_offset,
             record=record, record_offset=record_offset))
@@ -1196,6 +1265,29 @@ class ProvenanceTable(BaseTable):
     def append_columns(
             self, timestamp=None, timestamp_offset=None,
             record=None, record_offset=None):
+        """
+        Appends the specified arrays to the end of the columns of this
+        :class:`ProvenanceTable`. This allows many new rows to be added at once.
+
+        The ``timestamp`` and ``timestamp_offset`` parameters must be supplied
+        together, and meet the requirements for
+        :ref:`sec_encoding_ragged_columns` (see
+        :ref:`sec_tables_api_binary_columns` for more information). Likewise
+        for the ``record`` and ``record_offset`` columns
+
+        :param timestamp: The flattened timestamp array. Must be specified along
+            with ``timestamp_offset``. If not specified or None, an empty timestamp
+            value is stored for each node.
+        :type timestamp: numpy.ndarray, dtype=np.int8
+        :param timestamp_offset: The offsets into the ``timestamp`` array.
+        :type timestamp_offset: numpy.ndarray, dtype=np.uint32.
+        :param record: The flattened record array. Must be specified along
+            with ``record_offset``. If not specified or None, an empty record
+            value is stored for each node.
+        :type record: numpy.ndarray, dtype=np.int8
+        :param record_offset: The offsets into the ``record`` array.
+        :type record_offset: numpy.ndarray, dtype=np.uint32.
+        """
         self.ll_table.append_columns(dict(
             timestamp=timestamp, timestamp_offset=timestamp_offset,
             record=record, record_offset=record_offset))
@@ -1248,8 +1340,8 @@ class TableCollection(object):
     :ref:`requirements <sec_valid_tree_sequence_requirements>` that must be
     satisfied for these tables to be interpreted as a tree sequence.
 
-    To obtain a :class:`TreeSequence` instance corresponding to the current
-    state of a ``TableCollection``, please use the :meth:`.tree_sequence`
+    To obtain an immutable :class:`TreeSequence` instance corresponding to the
+    current state of a ``TableCollection``, please use the :meth:`.tree_sequence`
     method.
 
     :ivar individuals: The individual table.
@@ -1469,8 +1561,10 @@ class TableCollection(object):
         requirements to specify a valid tree sequence (but the resulting tables
         will).
 
-        Please see the :meth:`TreeSequence.simplify` method for a description
-        of the remaining parameters.
+        This is identical to :meth:`TreeSequence.simplify` but acts *in place* to
+        alter the data in this :class:`TableCollection`. Please see the
+        :meth:`TreeSequence.simplify` method for a description of the remaining
+        parameters.
 
         :param list[int] samples: A list of node IDs to retain as samples. If
             not specified or None, use all nodes marked with the IS_SAMPLE flag.
@@ -1494,7 +1588,7 @@ class TableCollection(object):
             in the output. (Default: False)
         :return: A numpy array mapping node IDs in the input tables to their
             corresponding node IDs in the output tables.
-        :rtype: numpy array (dtype=np.int32).
+        :rtype: numpy.ndarray (dtype=np.int32)
         """
         if filter_zero_mutation_sites is not None:
             # Deprecated in 0.6.1.
@@ -1515,7 +1609,7 @@ class TableCollection(object):
             reduce_to_site_topology=reduce_to_site_topology,
             keep_unary=keep_unary)
 
-    def map_ancestors(self, samples, ancestors):
+    def link_ancestors(self, samples, ancestors):
         """
         Returns an :class:`EdgeTable` instance describing a subset of the genealogical
         relationships between the nodes in``samples`` and ``ancestors``.
@@ -1533,12 +1627,12 @@ class TableCollection(object):
         ``ancestors``.
 
         The following table shows which ``parent->child`` pairs will be shown in the
-        output of ``map_ancestors``.
+        output of ``link_ancestors``.
         A node is a relevant descendant on a given interval if it also appears somewhere
         in the ``parent`` column of the outputted table.
 
         ========================  ===============================================
-        Type of relationship      Shown in output of ``map_ancestors``
+        Type of relationship      Shown in output of ``link_ancestors``
         ------------------------  -----------------------------------------------
         ``ancestor->sample``      Always
         ``ancestor1->ancestor2``  Only if ``ancestor2`` has a relevant descendant
@@ -1570,9 +1664,13 @@ class TableCollection(object):
         """
         samples = util.safe_np_int_cast(samples, np.int32)
         ancestors = util.safe_np_int_cast(ancestors, np.int32)
-        ll_edge_table = self.ll_tables.map_ancestors(samples, ancestors)
+        ll_edge_table = self.ll_tables.link_ancestors(samples, ancestors)
         return EdgeTable(ll_table=ll_edge_table)
 
+    def map_ancestors(self, *args, **kwargs):
+        # A deprecated alias for link_ancestors()
+        return self.link_ancestors(*args, **kwargs)
+
     def sort(self, edge_start=0):
         """
         Sorts the tables in place. This ensures that all tree sequence ordering
@@ -1647,19 +1745,69 @@ class TableCollection(object):
         self.ll_tables.deduplicate_sites()
         # TODO add provenance
 
+    def delete_sites(self, site_ids, record_provenance=True):
+        """
+        Remove the specified sites entirely from the sites and mutations tables in this
+        collection. This is identical to :meth:`TreeSequence.delete_sites` but acts
+        *in place* to alter the data in this :class:`TableCollection`.
+
+        :param list[int] site_ids: A list of site IDs specifying the sites to remove.
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
+        """
+        keep_sites = np.ones(len(self.sites), dtype=bool)
+        site_ids = util.safe_np_int_cast(site_ids, np.int32)
+        if np.any(site_ids < 0) or np.any(site_ids >= len(self.sites)):
+            raise ValueError("Site ID out of bounds")
+        keep_sites[site_ids] = 0
+        new_as, new_as_offset = keep_with_offset(
+            keep_sites, self.sites.ancestral_state,
+            self.sites.ancestral_state_offset)
+        new_md, new_md_offset = keep_with_offset(
+            keep_sites, self.sites.metadata, self.sites.metadata_offset)
+        self.sites.set_columns(
+            position=self.sites.position[keep_sites],
+            ancestral_state=new_as,
+            ancestral_state_offset=new_as_offset,
+            metadata=new_md,
+            metadata_offset=new_md_offset)
+        # We also need to adjust the mutations table, as it references into sites
+        keep_mutations = keep_sites[self.mutations.site]
+        new_ds, new_ds_offset = keep_with_offset(
+            keep_mutations, self.mutations.derived_state,
+            self.mutations.derived_state_offset)
+        new_md, new_md_offset = keep_with_offset(
+            keep_mutations, self.mutations.metadata, self.mutations.metadata_offset)
+        # Site numbers will have changed
+        site_map = np.cumsum(keep_sites, dtype=self.mutations.site.dtype) - 1
+        # Mutation numbers will change, so the parent references need altering
+        mutation_map = np.cumsum(keep_mutations, dtype=self.mutations.parent.dtype) - 1
+        # Map parent == -1 to -1, and check this has worked (assumes tskit.NULL == -1)
+        mutation_map = np.append(mutation_map, -1).astype(self.mutations.parent.dtype)
+        assert mutation_map[tskit.NULL] == tskit.NULL
+        self.mutations.set_columns(
+            site=site_map[self.mutations.site[keep_mutations]],
+            node=self.mutations.node[keep_mutations],
+            derived_state=new_ds,
+            derived_state_offset=new_ds_offset,
+            parent=mutation_map[self.mutations.parent[keep_mutations]],
+            metadata=new_md,
+            metadata_offset=new_md_offset)
+        if record_provenance:
+            # TODO replace with a version of https://github.com/tskit-dev/tskit/pull/243
+            parameters = {
+                "command": "delete_sites",
+                "TODO": "add parameters"
+            }
+            self.provenances.add_row(record=json.dumps(
+                provenance.get_provenance_dict(parameters)))
+
     def delete_intervals(self, intervals, simplify=True, record_provenance=True):
         """
-        Returns a copy of this set of tables for which information in the
-        specified list of genomic intervals has been deleted.  Edges spanning
-        these intervals are truncated or deleted, and sites falling within them are
-        discarded.
-
-        Note that node IDs may change as a result of this operation,
-        as by default :meth:`.simplify` is called on the resulting tables to
-        remove redundant nodes. If you wish to keep node IDs stable between
-        this set of tables and the returned tables, specify ``simplify=True``.
-
-        See also :meth:`.keep_intervals`.
+        Delete all information from this set of tables which lies *within* the
+        specified list of genomic intervals. This is identical to
+        :meth:`TreeSequence.delete_intervals` but acts *in place* to alter
+        the data in this :class:`TableCollection`.
 
         :param array_like intervals: A list (start, end) pairs describing the
             genomic intervals to delete. Intervals must be non-overlapping and
@@ -1667,28 +1815,26 @@ class TableCollection(object):
             2D numpy array with shape (N, 2), where N is the number of intervals.
         :param bool simplify: If True, run simplify on the tables so that nodes
             no longer used are discarded. (Default: True).
-        :param bool record_provenance: If True, record details of this operation
-            in the returned table collection's provenance information.
-            (Default: True).
-        :rtype: tskit.TableCollection
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
         """
-        return self.keep_intervals(
+        self.keep_intervals(
             util.negate_intervals(intervals, 0, self.sequence_length),
-            simplify=simplify, record_provenance=record_provenance)
+            simplify=simplify, record_provenance=False)
+        if record_provenance:
+            parameters = {
+                "command": "delete_intervals",
+                "TODO": "add parameters"
+            }
+            self.provenances.add_row(record=json.dumps(
+                provenance.get_provenance_dict(parameters)))
 
     def keep_intervals(self, intervals, simplify=True, record_provenance=True):
         """
-        Returns a copy of this set of tables which include only information in
-        the specified list of genomic intervals.  Edges are truncated to within
-        these intervals, and sites not falling within these intervals are
-        discarded.
-
-        Note that node IDs may change as a result of this operation,
-        as by default :meth:`.simplify` is called on the resulting tables to
-        remove redundant nodes. If you wish to keep node IDs stable between
-        this set of tables and the returned tables, specify ``simplify=True``.
-
-        See also :meth:`.delete_intervals`.
+        Delete all information from this set of tables which lies *outside* the
+        specified list of genomic intervals. This is identical to
+        :meth:`TreeSequence.keep_intervals` but acts *in place* to alter
+        the data in this :class:`TableCollection`.
 
         :param array_like intervals: A list (start, end) pairs describing the
             genomic intervals to keep. Intervals must be non-overlapping and
@@ -1696,82 +1842,120 @@ class TableCollection(object):
             2D numpy array with shape (N, 2), where N is the number of intervals.
         :param bool simplify: If True, run simplify on the tables so that nodes
             no longer used are discarded. (Default: True).
-        :param bool record_provenance: If True, record details of this operation
-            in the returned table collection's provenance information.
-            (Default: True).
-        :rtype: tskit.TableCollection
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
         """
-
-        def keep_with_offset(keep, data, offset):
-            # We need the astype here for 32 bit machines
-            lens = np.diff(offset).astype(np.int32)
-            return (data[np.repeat(keep, lens)],
-                    np.concatenate([
-                        np.array([0], dtype=offset.dtype),
-                        np.cumsum(lens[keep], dtype=offset.dtype)]))
-
         intervals = util.intervals_to_np_array(intervals, 0, self.sequence_length)
         if len(self.migrations) > 0:
-            raise ValueError("Migrations not supported by keep_intervals")
+            raise ValueError("Migrations not supported by keep_ and delete_ intervals")
 
-        tables = self.copy()
-        sites = self.sites
-        edges = self.edges
-        mutations = self.mutations
-        tables.edges.clear()
-        tables.sites.clear()
-        tables.mutations.clear()
-        keep_sites = np.repeat(False, sites.num_rows)
-        keep_mutations = np.repeat(False, mutations.num_rows)
+        edges = self.edges.copy()
+        self.edges.clear()
+        keep_sites = np.repeat(False, self.sites.num_rows)
         for s, e in intervals:
-            curr_keep_sites = np.logical_and(sites.position >= s, sites.position < e)
+            curr_keep_sites = np.logical_and(
+                self.sites.position >= s, self.sites.position < e)
             keep_sites = np.logical_or(keep_sites, curr_keep_sites)
-            new_as, new_as_offset = keep_with_offset(
-                curr_keep_sites, sites.ancestral_state, sites.ancestral_state_offset)
-            new_md, new_md_offset = keep_with_offset(
-                curr_keep_sites, sites.metadata, sites.metadata_offset)
-            keep_mutations = np.logical_or(
-                keep_mutations, curr_keep_sites[mutations.site])
             keep_edges = np.logical_not(np.logical_or(edges.right <= s, edges.left >= e))
-            tables.edges.append_columns(
+            self.edges.append_columns(
                 left=np.fmax(s, edges.left[keep_edges]),
                 right=np.fmin(e, edges.right[keep_edges]),
                 parent=edges.parent[keep_edges],
                 child=edges.child[keep_edges])
-            tables.sites.append_columns(
-                position=sites.position[curr_keep_sites],
-                ancestral_state=new_as,
-                ancestral_state_offset=new_as_offset,
-                metadata=new_md,
-                metadata_offset=new_md_offset)
-        new_ds, new_ds_offset = keep_with_offset(
-            keep_mutations, mutations.derived_state, mutations.derived_state_offset)
-        new_md, new_md_offset = keep_with_offset(
-            keep_mutations, mutations.metadata, mutations.metadata_offset)
-        site_map = np.cumsum(keep_sites, dtype=mutations.site.dtype) - 1
-        parent_map = np.cumsum(keep_mutations, dtype=mutations.parent.dtype) - 1
-        # parent -1 always maps to parent -1
-        parent_map = np.append(parent_map, np.array([-1], dtype=mutations.parent.dtype))
-        # Don't bother dealing with connected mutations as we are removing the whole site
-        tables.mutations.set_columns(
-            site=site_map[mutations.site[keep_mutations]],
-            node=mutations.node[keep_mutations],
-            derived_state=new_ds,
-            derived_state_offset=new_ds_offset,
-            parent=parent_map[mutations.parent[keep_mutations]],
-            metadata=new_md,
-            metadata_offset=new_md_offset)
-        tables.sort()
+        self.delete_sites(
+            np.where(np.logical_not(keep_sites))[0], record_provenance=False)
+        self.sort()
         if simplify:
-            tables.simplify()
+            self.simplify()
         if record_provenance:
             parameters = {
                 "command": "keep_intervals",
                 "TODO": "add parameters"
             }
-            tables.provenances.add_row(record=json.dumps(
+            self.provenances.add_row(record=json.dumps(
+                provenance.get_provenance_dict(parameters)))
+
+    def _check_trim_conditions(self):
+        if self.migrations.num_rows > 0:
+            raise ValueError(
+                "You cannot trim a tree sequence containing migrations")
+        if self.edges.num_rows == 0:
+            raise ValueError(
+                "Trimming a tree sequence with no edges would reduce the sequence length"
+                " to zero, which is not allowed")
+
+    def ltrim(self, record_provenance=True):
+        """
+        Reset the coordinate system used in these tables, changing the left and right
+        genomic positions in the edge table such that the leftmost edge now starts at
+        position 0. This is identical to :meth:`TreeSequence.ltrim` but acts *in place*
+        to alter the data in this :class:`TableCollection`.
+
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
+        """
+        self._check_trim_conditions()
+        leftmost = np.min(self.edges.left)
+        self.delete_sites(
+            np.where(self.sites.position < leftmost), record_provenance=False)
+        self.edges.set_columns(
+            left=self.edges.left - leftmost, right=self.edges.right - leftmost,
+            parent=self.edges.parent, child=self.edges.child)
+        self.sites.set_columns(
+            position=self.sites.position - leftmost,
+            ancestral_state=self.sites.ancestral_state,
+            ancestral_state_offset=self.sites.ancestral_state_offset,
+            metadata=self.sites.metadata,
+            metadata_offset=self.sites.metadata_offset)
+        self.sequence_length = self.sequence_length - leftmost
+        if record_provenance:
+            # TODO replace with a version of https://github.com/tskit-dev/tskit/pull/243
+            parameters = {
+                "command": "ltrim",
+            }
+            self.provenances.add_row(record=json.dumps(
+                provenance.get_provenance_dict(parameters)))
+
+    def rtrim(self, record_provenance=True):
+        """
+        Reset the ``sequence_length`` property so that the sequence ends at the end of
+        the last edge. This is identical to :meth:`TreeSequence.rtrim` but acts
+        *in place* to alter the data in this :class:`TableCollection`.
+
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
+        """
+        self._check_trim_conditions()
+        rightmost = np.max(self.edges.right)
+        self.delete_sites(
+            np.where(self.sites.position >= rightmost), record_provenance=False)
+        self.sequence_length = rightmost
+        if record_provenance:
+            # TODO replace with a version of https://github.com/tskit-dev/tskit/pull/243
+            parameters = {
+                "command": "rtrim",
+            }
+            self.provenances.add_row(record=json.dumps(
+                provenance.get_provenance_dict(parameters)))
+
+    def trim(self, record_provenance=True):
+        """
+        Trim away any empty regions on the right and left of the tree sequence encoded by
+        these tables. This is identical to :meth:`TreeSequence.trim` but acts *in place*
+        to alter the data in this :class:`TableCollection`.
+
+        :param bool record_provenance: If ``True``, add details of this operation
+            to the provenance table in this TableCollection. (Default: ``True``).
+        """
+        self.rtrim(record_provenance=False)
+        self.ltrim(record_provenance=False)
+        if record_provenance:
+            # TODO replace with a version of https://github.com/tskit-dev/tskit/pull/243
+            parameters = {
+                "command": "trim",
+            }
+            self.provenances.add_row(record=json.dumps(
                 provenance.get_provenance_dict(parameters)))
-        return tables
 
     def has_index(self):
         """
